==> tamejs-0.3.6.tgz: package/test/cases/12.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    "use strict" ;
    
    var assert = require ( "assert" ) ;
    var i = 0 ;
    var n = 11 ;
    
    exports [ "a test of return" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_1 = function (__tame_k) {
            var __tame_k_implicit = {};
            var __tame_fn_2 = function (__tame_k) {
                if (i < n + 4) {
                    var __tame_fn_3 = function (__tame_k) {
                        var __tame_fn_4 = function (__tame_k) {
                            var __tame_defers = new tame.Defers (__tame_k);
                            var __tame_fn_5 = function (__tame_k) {
                                setTimeout (
                                __tame_defers.defer ()
                                , 10 * Math . random ( ) ) ;
                                tame.callChain([__tame_k]);
                            };
                            __tame_fn_5(tame.end);
                            __tame_defers._fulfill();
                        };
                        var __tame_fn_8 = function (__tame_k) {
                            i ++ ;
                            var __tame_fn_6 = function (__tame_k) {
                                var __tame_fn_7 = function (__tame_k) {
                                    cb ( ) ;
                                    ;
                                    tame.callChain([tame.end, __tame_k]);
                                };
                                if (i == n) {
                                    tame.callChain([__tame_fn_7, __tame_k]);
                                } else {
                                    tame.callChain([__tame_k]);
                                }
                            };
                            tame.callChain([__tame_fn_6, __tame_k]);
                        };
                        tame.callChain([__tame_fn_4, __tame_fn_8, __tame_k]);
                    };
                    tame.callChain([__tame_fn_3, __tame_fn_2, __tame_k]);
                } else {
                    tame.callChain([__tame_k]);
                }
            };
            __tame_k_implicit.k_break = __tame_k;
            __tame_k_implicit.k_continue = function() { __tame_fn_2(__tame_k); };
            tame.callChain([__tame_fn_2, __tame_k]);
        };
        tame.callChain([__tame_fn_1, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert . equal ( i , n , "return at right moment" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.3.7.tgz: package/test/cases/12.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    "use strict" ;
    
    var assert = require ( "assert" ) ;
    var i = 0 ;
    var n = 11 ;
    
    exports [ "a test of return" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_1 = function (__tame_k) {
            var __tame_k_implicit = {};
            var __tame_fn_2 = function (__tame_k) {
                if (i < n + 4) {
                    var __tame_fn_3 = function (__tame_k) {
                        var __tame_fn_4 = function (__tame_k) {
                            var __tame_defers = new tame.Defers (__tame_k);
                            var __tame_fn_5 = function (__tame_k) {
                                setTimeout (
                                __tame_defers.defer ()
                                , 10 * Math . random ( ) ) ;
                                tame.callChain([__tame_k]);
                            };
                            __tame_fn_5(tame.end);
                            __tame_defers._fulfill();
                        };
                        var __tame_fn_9 = function (__tame_k) {
                            i ++ ;
                            var __tame_fn_6 = function (__tame_k) {
                                var __tame_fn_8 = function (__tame_k) {
                                    cb ( ) ;
                                    var __tame_fn_7 = function (__tame_k) {
                                            ;
                                            tame.callChain([tame.end, __tame_k]);
                                    };
                                    tame.callChain([__tame_fn_7, __tame_k]);
                                };
                                if (i == n) {
                                    tame.callChain([__tame_fn_8, __tame_k]);
                                } else {
                                    tame.callChain([__tame_k]);
                                }
                            };
                            tame.callChain([__tame_fn_6, __tame_k]);
                        };
                        tame.callChain([__tame_fn_4, __tame_fn_9, __tame_k]);
                    };
                    tame.callChain([__tame_fn_3, __tame_fn_2, __tame_k]);
                } else {
                    tame.callChain([__tame_k]);
                }
            };
            __tame_k_implicit.k_break = __tame_k;
            __tame_k_implicit.k_continue = function() { __tame_fn_2(__tame_k); };
            tame.callChain([__tame_fn_2, __tame_k]);
        };
        tame.callChain([__tame_fn_1, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert . equal ( i , n , "return at right moment" ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
